@@ -65,6 +65,8 @@ class MpvPlayer(BasePlayer):
                     continue
                 if "=" in argToAdd:
                     (argName, argValue) = argToAdd.split("=", 1)
+                    if argValue[0] == '"' and argValue[-1] == '"':
+                        argValue = argValue[1:-1]
                 else:
                     argName = argToAdd
                     argValue = "yes"
@@ -211,6 +213,9 @@ class MpvPlayer(BasePlayer):
         else:
             return self._position
 
+    def eofDetected(self):
+        self._client.eofReportedByPlayer()
+
     def _storePosition(self, value):
         if value is None:
             self._client.ui.showDebugMessage("NONE TYPE POSITION!")
@@ -418,11 +423,13 @@ class MpvPlayer(BasePlayer):
 
     def _handleUnknownLine(self, line):
         self.mpvErrorCheck(line)
-
         if "<chat>" in line:
             line = line.replace(constants.MPV_INPUT_BACKSLASH_SUBSTITUTE_CHARACTER, "\\")
             self._listener.sendChat(line[6:-7])
 
+        if "<eof>" in line:
+            self.eofDetected()
+
         if "<paused=" in line and ", pos=" in line:
             update_string = line.replace(">", "<").replace("=", "<").replace(", ", "<").split("<")
             paused_update = update_string[2]
@@ -590,15 +597,25 @@ class MpvPlayer(BasePlayer):
             # to allow that version of python to be executed in the mpv subprocess.
             if isMacOS():
                 try:
-                    pythonLibs = subprocess.check_output(['/usr/bin/python', '-E', '-c',
+                    env['PATH'] = '/opt/homebrew/bin:/usr/local/bin:/usr/bin'
+                    ytdl_path = subprocess.check_output(['which', 'youtube-dl'], text=True, env=env).rstrip('\n')
+                    with open(ytdl_path, 'rb') as f:
+                        ytdl_shebang = f.readline()
+                    ytdl_python = ytdl_shebang.decode('utf-8').lstrip('!#').rstrip('\n')
+                    if '/usr/bin/env' in ytdl_python:
+                        python_name = ytdl_python.split(' ')[1]
+                        python_executable = subprocess.check_output(['which', python_name], text=True, env=env).rstrip('\n')
+                    else:
+                        python_executable = ytdl_python
+                    pythonLibs = subprocess.check_output([python_executable, '-E', '-c',
                                                           'import sys; print(sys.path)'],
                                                           text=True, env=dict())
                     pythonLibs = ast.literal_eval(pythonLibs)
                     pythonPath = ':'.join(pythonLibs[1:])
-                except:
+                except Exception as e:
                     pythonPath = None
                 if pythonPath is not None:
-                    env['PATH'] = '/usr/bin:/usr/local/bin'
+                    env['PATH'] = python_executable + ':' + env['PATH']
                     env['PYTHONPATH'] = pythonPath
             try:
                 socket = self.mpv_arguments.get('input-ipc-server')
