@@ -77,7 +77,13 @@ non_us_chars = {
     'И','и','Й','й','К','к','Л','л','М','м','Н','н','О','о','П','п',
     'Р','р','С','с','Т','т','У','у','Ф','ф','Х','х','Ц','ц','Ч','ч',
     'Ш','ш','Щ','щ','Ъ','ъ','Ы','ы','Ь','ь','Э','э','Ю','ю','Я','я',
-    '≥','≠','Ğ','Ş','ı','ğ','ş'
+    '≥','≠','Ğ','Ş','ı','ğ','ş',
+	'ç', 'ñ',
+    '´',
+    '`',
+    '^',
+    '~', 'ẽ', 'ĩ', 'ũ',
+    '¨',
 }
 
 function format_scrolling(xpos, ypos, text)
@@ -289,6 +295,13 @@ end
 
 chat_timer=mp.add_periodic_timer(TICK_INTERVAL, chat_update)
 
+mp.observe_property('eof-reached', 'bool', function(e)
+	if mp.get_property_native("eof-reached") == true then
+		mp.command('print-text "<eof>"')
+	end
+end)
+
+
 mp.register_script_message('chat', function(e)
 	add_chat(e)
 end)
@@ -979,7 +992,7 @@ function readyMpvAfterSettingsKnown()
 				add_repl_alpharow_bindings(alpharowbindings)
 				mp.add_forced_key_binding('tab', handle_tab)
 			end
-        end 
+        end
         syncplayintfSet = true
     end
 end
